// Copyright (c) 2022-2023 VMware Carbon Black, all rights reserved

package hinttype

//go:generate go run golang.org/x/tools/cmd/stringer -type=HintType

// HintType -- Enumeration for hints generated
type HintType int

// NOTE: Changes here should also be reflected in `test/functional/suites/lib/models/enumerations.py`
// NOTE: No definition for type 1

// NOTE: Keep in sync with:
//   - https://gitlab.bit9.local/cb-defense/cbd/-/blob/main/backend/domainModel/src/main/java/com/scargo/domainmodel/request/support/ResponseHint.java
//
//goland:noinspection GoSnakeCaseUsage
const (
	NEW_POLICY                   HintType = iota
	NEW_CONFIG_DATA              HintType = 2  // Send the Configuration request. The configuration data for the device has changed so the sensor should get the latest settings
	HASH_LIST_REFRESH            HintType = 3  // Send the Hash List Refresh request to retrieve a list a hashes for which the sensor needs to refresh reputation
	HASH_LIST_UPLOAD             HintType = 4  // Send the Hash List Upload request to retrieve a list of hashes for which the sensor needs to upload to the cloud
	CONFER_UPLOAD                HintType = 5  // Send the Files Upload request to push Confer configuration log database etc. files to the cloud
	INVALIDATE_NON_WHITELIST_REP HintType = 6  // Inform the agent to purge all non-whitelisted reputation
	STATUS_UPDATE                HintType = 7  // Get the device to send a status request
	APC_UPLOAD                   HintType = 8  // Upload file to APC
	RESUBMIT                     HintType = 9  // Request the device to resubmit in a short while
	REQUEST_NEWS                 HintType = 10 // Request device to send news feed request
	VT_ANALYSIS_UPLOAD           HintType = 11 // Ask the device to upload the file for analyis on VirusTotal
	SOFTWARE_UPGRADE             HintType = 12 // Indicate that there is a newer sensor kit available
	SOFTWARE_PATCH               HintType = 13 // Indicate that there is a software patch available
	YARA_AV_SIGNATURES           HintType = 14 // Indicate that YARA AV Signatures are available
	YARA_NETWORK_SIGNATURES      HintType = 15 // Indicate that YARA network Signatures are available
	YARA_PE_HEADER_SIGNATURES    HintType = 16 // Indicate that YARA PE header Signatures are available
	IP_BLOCK_LIST                HintType = 17 // Indicate that there is a change in the ip block list
	IP_FORENSICS_LIST            HintType = 18 // Indicate that there is a change in the ip forensics list
	HASH_FORENSICS_LIST          HintType = 19 // Indicate that there is a change in the hash forensics list
	ONETIME_HASH_DELETE_LIST     HintType = 20 // Indicate that there is a change in the one-time delete hash list
	PERMANENT_HASH_DELETE_LIST   HintType = 21 // Indicate that there is a change in the permanent delete hash list
	SENSOR_CERTIFICATE_UPLOAD    HintType = 22 // Sensor certificate upload
	SENSOR_TRIGGER_PERFMON       HintType = 23 // Trigger performance monitoring script on the sensor
	SENSOR_ACTION                HintType = 24 // Indicate that there are sensor actions
	KILL_SWITCH_ON               HintType = 25 // Kill switch on for all devices
	ZIP_CONTAINER                HintType = 26 // Indicate a new ransomware canary payload is available
	UNINSTALL_CODE               HintType = 27 // A new sensor uninstall code is available
	LIVE_QUERY                   HintType = 28 // A new live query is available
	ASYNCREPUTATION              HintType = 29 // Async reputation
	BLADE_ACTION                 HintType = 30 // Indicates there is a new blade action for the sensor
	REREGISTER                   HintType = 31 // The device has to reregister itself
)

//goland:noinspection GoSnakeCaseUsage
const NUM_HINTS = 32

//goland:noinspection GoSnakeCaseUsage
var ALL_HINT_STRINGS = getAllHintTypeStrings()

func getAllHintTypeStrings() map[string]int {
	temp := make(map[string]int, NUM_HINTS)
	for i := 0; i < NUM_HINTS-1; i++ {
		switch i {
		case 0:
			temp[_HintType_name_0] = 0
		default:
			firstIndex := _HintType_index_1[i-1]
			secondIndex := _HintType_index_1[i]
			temp[_HintType_name_1[firstIndex:secondIndex]] = i + 1
		}
	}
	return temp
}
